diff --git a/curweather/README.md b/curweather/README.md
new file mode 100644
index 00000000..ff43f248
--- /dev/null
+++ b/curweather/README.md
@@ -0,0 +1,29 @@
+Current Weather
+===============
+
+If activated by your user this addon adds a widget to the users network tab
+sidebar showing current weather informations (temperature, relative humidity,
+wind conditions and preassure) from [OpenWeatherMap](http://openweathermap.org).
+The user can configure the location as e.g. *Berlin,DE* or the zip code "14476,DE".
+
+The language for the request at OpenWeatherMap is set to the UI language of
+friendica. If the string for the description of the current weather conditions
+is available in this language depends on OpenWeatherMap, fallback is english.
+
+**You should get an APPID from OpenWeatherMap if you want to use this widget.**
+You can register [here](http://openweathermap.org/register).
+
+Credits
+-------
+
+* Tony Baldwin wrote the original addon for Friendica
+* Fabio Comuni
+* Tobias Diekershoff switched the sources to OpenWeatherMap after the original
+ provider turned off support for locations outside of the USA.
+
+Known Issues
+------------
+
+* Localization does not work (Jul 15) data requested via XML are EN only but
+ have moew information available compared to data requested via JSON which is
+ available in other languages as well. Right now we use the XML dataset
diff --git a/curweather/curweather.css b/curweather/curweather.css
index 6c127963..69574ff0 100644
--- a/curweather/curweather.css
+++ b/curweather/curweather.css
@@ -1,10 +1,11 @@
-
-#curtemp-settings-label, #curtemp-location-label, #curtemp-enable-label {
- float: left;
- width: 200px;
- margin-bottom: 25px;
+#curweather-network img {
+ float: left;
+ margin: 30px 10px;
}
-#curtemp-network {
- float: left;
+ul.curweather-details li {
+ list-type: none;
+}
+p.curweather-footer {
+ font-size: 0.8em;
}
diff --git a/curweather/curweather.php b/curweather/curweather.php
index 67d5939e..59d7e378 100644
--- a/curweather/curweather.php
+++ b/curweather/curweather.php
@@ -1,29 +1,78 @@
- Find the location code for the station or airport nearest you here.
- * Version: 1.0
+ * Description: Shows current weather conditions for user's location on their network page.
+ * Version: 1.1
* Author: Tony Baldwin
* Author: Fabio Comuni
+ * Author: Tobias Diekershoff
*
*/
-require_once('addon/curweather/getweather.php');
+
+require_once('include/network.php');
+require_once("mod/proxy.php");
+require_once('include/text.php');
+
+// get the weather data from OpenWeatherMap
+function getWeather( $loc, $units='metric', $lang='en', $appid='', $cachetime=0) {
+ $url = "http://api.openweathermap.org/data/2.5/weather?q=".$loc."&appid=".$appid."&lang=".$lang."&units=".$units."&mode=xml";
+ $cached = Cache::get('curweather'.md5($url));
+ $now = new DateTime();
+ if (!is_null($cached)) {
+ $cdate = get_pconfig(local_user(), 'curweather', 'last');
+ $cached = unserialize($cached);
+ if ($cdate + $cachetime > $now->getTimestamp()) {
+ return $cached;
+ }
+ }
+ try {
+ $res = new SimpleXMLElement(fetch_url($url));
+ } catch (Exception $e) {
+ info(t('Error fetching weather data.\nError was: '.$e->getMessage()));
+ return false;
+ }
+ if ((string)$res->temperature['unit']==='metric') {
+ $tunit = '°C';
+ $wunit = 'm/s';
+ } else {
+ $tunit = '°F';
+ $wunit = 'mph';
+ }
+ if ( trim((string)$res->weather['value']) == trim((string)$res->clouds['name']) ) {
+ $desc = (string)$res->clouds['name'];
+ } else {
+ $desc = (string)$res->weather['value'].', '.(string)$res->clouds['name'];
+ }
+ $r = array(
+ 'city'=> (string) $res->city['name'][0],
+ 'country' => (string) $res->city->country[0],
+ 'lat' => (string) $res->city->coord['lat'],
+ 'lon' => (string) $res->city->coord['lon'],
+ 'temperature' => (string) $res->temperature['value'][0].$tunit,
+ 'pressure' => (string) $res->pressure['value'].(string)$res->pressure['unit'],
+ 'humidity' => (string) $res->humidity['value'].(string)$res->humidity['unit'],
+ 'descripion' => $desc,
+ 'wind' => (string)$res->wind->speed['name'].' ('.(string)$res->wind->speed['value'].$wunit.')',
+ 'update' => (string)$res->lastupdate['value'],
+ 'icon' => (string)$res->weather['icon']
+ );
+ set_pconfig(local_user(), 'curweather', 'last', $now->getTimestamp());
+ Cache::set('curweather'.md5($url), serialize($r));
+ return $r;
+}
function curweather_install() {
register_hook('network_mod_init', 'addon/curweather/curweather.php', 'curweather_network_mod_init');
register_hook('plugin_settings', 'addon/curweather/curweather.php', 'curweather_plugin_settings');
register_hook('plugin_settings_post', 'addon/curweather/curweather.php', 'curweather_plugin_settings_post');
-
}
function curweather_uninstall() {
unregister_hook('network_mod_init', 'addon/curweather/curweather.php', 'curweather_network_mod_init');
unregister_hook('plugin_settings', 'addon/curweather/curweather.php', 'curweather_plugin_settings');
unregister_hook('plugin_settings_post', 'addon/curweather/curweather.php', 'curweather_plugin_settings_post');
-
}
-
function curweather_network_mod_init(&$fk_app,&$b) {
if(! intval(get_pconfig(local_user(),'curweather','curweather_enable')))
@@ -31,27 +80,56 @@ function curweather_network_mod_init(&$fk_app,&$b) {
$fk_app->page['htmlhead'] .= '' . "\r\n";
- // the getweather file does all the work here
- // the $rpt value is needed for location
- // which getweather uses to fetch the weather data for weather and temp
+ // $rpt value is needed for location
+ // $lang will be taken from the browser session to honour user settings
+ // TODO $lang does not work if the default settings are used
+ // and not all response strings are translated
+ // $units can be set in the settings by the user
+ // $appid is configured by the admin in the admin panel
+ // those parameters will be used to get: cloud status, temperature, preassure
+ // and relative humidity for display, also the relevent area of the map is
+ // linked from lat/log of the reply of OWMp
$rpt = get_pconfig(local_user(), 'curweather', 'curweather_loc');
- $wxdata = GetWeather::get($rpt);
- $temp = $wxdata['TEMPERATURE_STRING'];
- $weather = $wxdata['WEATHER'];
- $rhumid = $wxdata['RELATIVE_HUMIDITY'];
- $pressure = $wxdata['PRESSURE_STRING'];
- $wind = $wxdata['WIND_STRING'];
- $curweather = '
+
diff --git a/curweather/test.php b/curweather/test.php
deleted file mode 100644
index cd51c23c..00000000
--- a/curweather/test.php
+++ /dev/null
@@ -1,5 +0,0 @@
-
-* Author: Tobias Diekershoff
+* Author: Tobias Diekershoff
*/
function irc_install() {
diff --git a/krynn/krynn.css b/krynn/krynn.css
deleted file mode 100755
index 466a3ecd..00000000
--- a/krynn/krynn.css
+++ /dev/null
@@ -1,14 +0,0 @@
-
-
-
-#krynn-enable-label {
- float: left;
- width: 200px;
- margin-bottom: 25px;
-}
-
-#krynn-checkbox {
- float: left;
-}
-
-
diff --git a/krynn/krynn.php b/krynn/krynn.php
deleted file mode 100755
index de968713..00000000
--- a/krynn/krynn.php
+++ /dev/null
@@ -1,173 +0,0 @@
-
- * Planets Author: Tony Baldwin
- * Author: Dylan Thiedeke
- *
- *"My body was my sacrifice... for my magic. This damage is permanent." - Raistlin Majere
- */
-
-
-function krynn_install() {
-
- /**
- *
- * Our demo plugin will attach in three places.
- * The first is just prior to storing a local post.
- *
- */
-
- register_hook('post_local', 'addon/krynn/krynn.php', 'krynn_post_hook');
-
- /**
- *
- * Then we'll attach into the plugin settings page, and also the
- * settings post hook so that we can create and update
- * user preferences.
- *
- */
-
- register_hook('plugin_settings', 'addon/krynn/krynn.php', 'krynn_settings');
- register_hook('plugin_settings_post', 'addon/krynn/krynn.php', 'krynn_settings_post');
-
- logger("installed krynn");
-}
-
-
-function krynn_uninstall() {
-
- /**
- *
- * uninstall unregisters any hooks created with register_hook
- * during install. It may also delete configuration settings
- * and any other cleanup.
- *
- */
-
- unregister_hook('post_local', 'addon/krynn/krynn.php', 'krynn_post_hook');
- unregister_hook('plugin_settings', 'addon/krynn/krynn.php', 'krynn_settings');
- unregister_hook('plugin_settings_post', 'addon/krynn/krynn.php', 'krynn_settings_post');
-
-
- logger("removed krynn");
-}
-
-
-
-function krynn_post_hook($a, &$item) {
-
- /**
- *
- * An item was posted on the local system.
- * We are going to look for specific items:
- * - A status post by a profile owner
- * - The profile owner must have allowed our plugin
- *
- */
-
- logger('krynn invoked');
-
- if(! local_user()) /* non-zero if this is a logged in user of this system */
- return;
-
- if(local_user() != $item['uid']) /* Does this person own the post? */
- return;
-
- if($item['parent']) /* If the item has a parent, this is a comment or something else, not a status post. */
- return;
-
- /* Retrieve our personal config setting */
-
- $active = get_pconfig(local_user(), 'krynn', 'enable');
-
- if(! $active)
- return;
-
- /**
- *
- * OK, we're allowed to do our stuff.
- * Here's what we are going to do:
- * load the list of timezone names, and use that to generate a list of krynn locales.
- * Then we'll pick one of those at random and put it in the "location" field for the post.
- *
- */
-
- $krynn = array('Ansalon','Abanasinia','Solace','Haven','Gateway','Qualinost','Ankatavaka','Pax Tharkas','Ergoth','Newsea','Straights of Schallsea','Plains of Dust','Tarsis','Barren Hills','Que Shu','Citadel of Light','Solinari','Hedge Maze','Tower of High Sorcery','Inn of the Last Home','Last Heroes Tomb','Academy of Sorcery','Gods Row','Temple of Majere','Temple of Kiri-Jolith','Temple of Mishakal','Temple of Zeboim','The Trough','Sad Town','Xak Tsaroth','Zhaman','Skullcap','Saifhum','Karthay','Mithas','Kothas','Silver Dragon Mountain','Silvanesti');
-
- $planet = array_rand($krynn,1);
- $item['location'] = $krynn[$planet];
-
- return;
-}
-
-
-
-
-/**
- *
- * Callback from the settings post function.
- * $post contains the $_POST array.
- * We will make sure we've got a valid user account
- * and if so set our configuration setting for this person.
- *
- */
-
-function krynn_settings_post($a,$post) {
- if(! local_user())
- return;
- if($_POST['krynn-submit'])
- set_pconfig(local_user(),'krynn','enable',intval($_POST['krynn']));
-}
-
-
-/**
- *
- * Called from the Plugin Setting form.
- * Add our own settings info to the page.
- *
- */
-
-
-
-function krynn_settings(&$a,&$s) {
-
- if(! local_user())
- return;
-
- /* Add our stylesheet to the page so we can make our settings look nice */
-
- $a->page['htmlhead'] .= '' . "\r\n";
-
- /* Get the current state of our config variable */
-
- $enabled = get_pconfig(local_user(),'krynn','enable');
-
- $checked = (($enabled) ? ' checked="checked" ' : '');
-
- /* Add some HTML to the existing form */
-
- $s .= '';
- $s .= '
';
/* provide a submit button */
diff --git a/snautofollow/snautofollow.php b/snautofollow/snautofollow.php
index 2d953d5b..ca19d650 100644
--- a/snautofollow/snautofollow.php
+++ b/snautofollow/snautofollow.php
@@ -4,7 +4,8 @@
* Description: Automatic follow/friend of statusnet people who mention/follow you
* Version: 1.0
* Author: Mike Macgirvin
- * Status: Unsupported
+ *
+ *
*/
diff --git a/statusnet/statusnet.php b/statusnet/statusnet.php
index 7041c399..bda26a57 100644
--- a/statusnet/statusnet.php
+++ b/statusnet/statusnet.php
@@ -1,7 +1,7 @@
* Author: Michael Vogel
@@ -35,7 +35,7 @@
/***
* We have to alter the TwitterOAuth class a little bit to work with any GNU Social
* installation abroad. Basically it's only make the API path variable and be happy.
*
* Thank you guys for the Twitter compatible API!
@@ -119,7 +119,7 @@ function statusnet_install() {
register_hook('jot_networks', 'addon/statusnet/statusnet.php', 'statusnet_jot_nets');
register_hook('cron', 'addon/statusnet/statusnet.php', 'statusnet_cron');
register_hook('prepare_body', 'addon/statusnet/statusnet.php', 'statusnet_prepare_body');
- logger("installed GNU Social");
+ logger("installed statusnet");
}
@@ -148,20 +148,20 @@ function statusnet_jot_nets(&$a,&$b) {
$statusnet_defpost = get_pconfig(local_user(),'statusnet','post_by_default');
$selected = ((intval($statusnet_defpost) == 1) ? ' checked="checked" ' : '');
$b .= '
'
- . t('Post to GNU Social') . '
';
+ . t('Post to StatusNet') . '
';
}
}
function statusnet_settings_post ($a,$post) {
if(! local_user())
return;
- // don't check GNU Social settings if GNU Social submit button is not clicked
+ // don't check statusnet settings if statusnet submit button is not clicked
if (!x($_POST,'statusnet-submit'))
return;
if (isset($_POST['statusnet-disconnect'])) {
/***
- * if the GNU Social-disconnect checkbox is set, clear the GNU Social configuration
+ * if the statusnet-disconnect checkbox is set, clear the statusnet configuration
*/
del_pconfig(local_user(), 'statusnet', 'consumerkey');
del_pconfig(local_user(), 'statusnet', 'consumersecret');
@@ -178,7 +178,7 @@ function statusnet_settings_post ($a,$post) {
} else {
if (isset($_POST['statusnet-preconf-apiurl'])) {
/***
* If the user used one of the preconfigured GNU Social server credentials
* use them. All the data are available in the global config.
* Check the API Url never the less and blame the admin if it's not working ^^
*/
@@ -200,7 +200,7 @@ function statusnet_settings_post ($a,$post) {
goaway($a->get_baseurl().'/settings/connectors');
} else {
if (isset($_POST['statusnet-consumersecret'])) {
// check if we can reach the API of the GNU Social server
// we'll check the API Version for that, if we don't get one we'll try to fix the path but will
// resign quickly after this one try to fix the path ;-)
$apibase = $_POST['statusnet-baseapi'];
@@ -222,18 +222,18 @@ function statusnet_settings_post ($a,$post) {
set_pconfig(local_user(), 'statusnet', 'baseapi', $apibase );
} else {
// still not the correct API base, let's do noting
- notice( t('We could not contact the GNU Social API with the Path you entered.').EOL );
+ notice( t('We could not contact the StatusNet API with the Path you entered.').EOL );
}
}
goaway($a->get_baseurl().'/settings/connectors');
} else {
if (isset($_POST['statusnet-pin'])) {
- // if the user supplied us with a PIN from GNU Social, let the magic of OAuth happen
+ // if the user supplied us with a PIN from StatusNet, let the magic of OAuth happen
$api = get_pconfig(local_user(), 'statusnet', 'baseapi');
$ckey = get_pconfig(local_user(), 'statusnet', 'consumerkey' );
$csecret = get_pconfig(local_user(), 'statusnet', 'consumersecret' );
// the token and secret for which the PIN was generated were hidden in the settings
// form as token and token2, we need a new connection to GNU Social using these token
// and secret to request a Access Token with the PIN
$connection = new StatusNetOAuth($api, $ckey, $csecret, $_POST['statusnet-token'], $_POST['statusnet-token2']);
$token = $connection->getAccessToken( $_POST['statusnet-pin'] );
@@ -256,7 +256,7 @@ function statusnet_settings_post ($a,$post) {
if (!intval($_POST['statusnet-mirror']))
del_pconfig(local_user(),'statusnet','lastid');
- info( t('GNU Social settings updated.') . EOL);
+ info( t('StatusNet settings updated.') . EOL);
}}}}
}
function statusnet_settings(&$a,&$s) {
@@ -291,11 +291,11 @@ function statusnet_settings(&$a,&$s) {
$css = (($enabled) ? '' : '-disabled');
$s .= '';
- $s .= '
'. t('GNU Social Import/Export/Mirror').'
';
+ $s .= '
'. t('StatusNet Import/Export/Mirror').'
';
$s .= '';
$s .= '
';
$s .= '';
- $s .= '
'. t('GNU Social Import/Export/Mirror').'
';
+ $s .= '
'. t('StatusNet Import/Export/Mirror').'
';
$s .= '';
if ( (!$ckey) && (!$csecret) ) {
@@ -304,14 +304,14 @@ function statusnet_settings(&$a,&$s) {
*/
$globalsn = get_config('statusnet', 'sites');
/***
* lets check if we have one or more globally configured GNU Social
* server OAuth credentials in the configuration. If so offer them
* with a little explanation to the user as choice - otherwise
* ignore this option entirely.
*/
if (! $globalsn == null) {
- $s .= '
' . t('Globally Available GNU Social OAuthKeys') . '
';
- $s .= '
'. t("There are preconfigured OAuth key pairs for some GNU Social servers available. If you are using one of them, please use these credentials. If not feel free to connect to any other GNU Social instance \x28see below\x29.") .'
';
+ $s .= '
' . t('Globally Available StatusNet OAuthKeys') . '
';
+ $s .= '
'. t("There are preconfigured OAuth key pairs for some StatusNet servers available. If you are using one of them, please use these credentials. If not feel free to connect to any other StatusNet instance \x28see below\x29.") .'
'. t('No consumer key pair for GNU Social found. Register your Friendica Account as an desktop client on your GNU Social account, copy the consumer key pair here and enter the API base root. Before you register your own OAuth key pair ask the administrator if there is already a key pair for this Friendica installation at your favorited GNU Social installation.') .'
';
+ $s .= '
'. t('No consumer key pair for StatusNet found. Register your Friendica Account as an desktop client on your StatusNet account, copy the consumer key pair here and enter the API base root. Before you register your own OAuth key pair ask the administrator if there is already a key pair for this Friendica installation at your favorited StatusNet installation.') .'
';
$s .= '
';
$s .= '';
$s .= ' ';
@@ -331,7 +331,7 @@ function statusnet_settings(&$a,&$s) {
$s .= '';
$s .= ' ';
$s .= '';
- //$s .= '';
+ //$s .= '';
//$s .= ' ';
$s .= '';
$s .= '';
@@ -342,10 +342,10 @@ function statusnet_settings(&$a,&$s) {
*/
if ( (!$otoken) && (!$osecret) ) {
/***
- * the user has not yet connected the account to GNU Social
+ * the user has not yet connected the account to statusnet
* get a temporary OAuth key/secret pair and display a button with
* which the user can request a PIN to connect the account to a
- * account at GNU Social
+ * account at statusnet
*/
$connection = new StatusNetOAuth($api, $ckey, $csecret);
$request_token = $connection->getRequestToken('oob');
@@ -353,10 +353,10 @@ function statusnet_settings(&$a,&$s) {
/***
* make some nice form
*/
- $s .= '
'. t('To connect to your GNU Social account click the button below to get a security code from GNU Social which you have to copy into the input box below and submit the form. Only your public posts will be posted to GNU Social.') .'
';
- $s .= '';
+ $s .= '
'. t('To connect to your StatusNet account click the button below to get a security code from StatusNet which you have to copy into the input box below and submit the form. Only your public posts will be posted to StatusNet.') .'
';
$s .= '';
} else {
/***
* we have an OAuth key / secret pair for the user
- * so let's give a chance to disable the postings to GNU Social
+ * so let's give a chance to disable the postings to statusnet
*/
$connection = new StatusNetOAuth($api,$ckey,$csecret,$otoken,$osecret);
$details = $connection->get('account/verify_credentials');
$s .= '
'. t('If enabled all your public postings can be posted to the associated GNU Social account. You can choose to do so by default (here) or for every posting separately in the posting options when writing the entry.') .'
';
+ $s .= '
'. t('If enabled all your public postings can be posted to the associated StatusNet account. You can choose to do so by default (here) or for every posting separately in the posting options when writing the entry.') .'
';
if ($a->user['hidewall']) {
- $s .= '
'. t('Note: Due your privacy settings (Hide your profile details from unknown viewers?) the link potentially included in public postings relayed to GNU Social will lead the visitor to a blank page informing the visitor that the access to your profile has been restricted.') .'
';
+ $s .= '
'. t('Note: Due your privacy settings (Hide your profile details from unknown viewers?) the link potentially included in public postings relayed to StatusNet will lead the visitor to a blank page informing the visitor that the access to your profile has been restricted.') .'
';
}
$s .= '
';
- $s .= '';
+ $s .= '';
$s .= '';
$s .= '';
- $s .= '';
+ $s .= '';
$s .= '';
$s .= '';
- $s .= '';
+ $s .= '';
$s .= '';
$s .= '';
@@ -470,7 +470,7 @@ function statusnet_action($a, $uid, $pid, $action) {
function statusnet_post_hook(&$a,&$b) {
/**
- * Post to GNU Social
+ * Post to statusnet
*/
if (!get_pconfig($b["uid"],'statusnet','import')) {
@@ -484,11 +484,11 @@ function statusnet_post_hook(&$a,&$b) {
if($b['parent'] != $b['id']) {
logger("statusnet_post_hook: parameter ".print_r($b, true), LOGGER_DATA);
- // Looking if its a reply to a GNU Social post
+ // Looking if its a reply to a statusnet post
$hostlength = strlen($hostname) + 2;
if ((substr($b["parent-uri"], 0, $hostlength) != $hostname."::") AND (substr($b["extid"], 0, $hostlength) != $hostname."::")
AND (substr($b["thr-parent"], 0, $hostlength) != $hostname."::")) {
- logger("statusnet_post_hook: no GNU Social post ".$b["parent"]);
+ logger("statusnet_post_hook: no statusnet post ".$b["parent"]);
return;
}
@@ -541,14 +541,14 @@ function statusnet_post_hook(&$a,&$b) {
if($b['deleted'] || ($b['created'] !== $b['edited']))
return;
- // if posts comes from GNU Social don't send it back
+ // if posts comes from statusnet don't send it back
if($b['extid'] == NETWORK_STATUSNET)
return;
if($b['app'] == "StatusNet")
return;
- logger('GNU Socialpost invoked');
+ logger('statusnet post invoked');
load_pconfig($b['uid'], 'statusnet');
@@ -560,7 +560,7 @@ function statusnet_post_hook(&$a,&$b) {
if($ckey && $csecret && $otoken && $osecret) {
- // If it's a repeated message from GNU Social then do a native retweet and exit
+ // If it's a repeated message from statusnet then do a native retweet and exit
if (statusnet_is_retweet($a, $b['uid'], $b['body']))
return;
@@ -621,7 +621,7 @@ function statusnet_post_hook(&$a,&$b) {
set_pconfig($b["uid"], "statusnet", "application_name", strip_tags($result->source));
if ($result->error) {
- logger('Send to GNU Social failed: "'.$result->error.'"');
+ logger('Send to StatusNet failed: "'.$result->error.'"');
} elseif ($iscomment) {
logger('statusnet_post: Update extid '.$result->id." for post id ".$b['id']);
q("UPDATE `item` SET `extid` = '%s', `body` = '%s' WHERE `id` = %d",
@@ -1284,7 +1284,7 @@ function statusnet_checknotification($a, $uid, $own_url, $top_item, $postarray)
if(!count($own_user))
return;
- // Is it me from GNU Social?
+ // Is it me from statusnet?
if (link_compare($own_user[0]["url"], $postarray['author-link']))
return;
@@ -1357,7 +1357,7 @@ function statusnet_fetchhometimeline($a, $uid, $mode = 1) {
if(count($r)) {
$nick = $r[0]["nick"];
} else {
- logger("statusnet_fetchhometimeline: Own GNU Social contact not found for user ".$uid, LOGGER_DEBUG);
+ logger("statusnet_fetchhometimeline: Own statusnet contact not found for user ".$uid, LOGGER_DEBUG);
return;
}
@@ -1647,7 +1647,7 @@ function statusnet_convertmsg($a, $body, $no_tags = false) {
$str_tags .= ',';
if ($mtch[1] == "#") {
- // Replacing the hash tags that are directed to the GNU Social server with internal links
+ // Replacing the hash tags that are directed to the statusnet server with internal links
$snhash = "#[url=".$mtch[2]."]".$mtch[3]."[/url]";
$frdchash = '#[url='.$a->get_baseurl().'/search?tag='.rawurlencode($mtch[3]).']'.$mtch[3].'[/url]';
$body = str_replace($snhash, $frdchash, $body);
@@ -1656,7 +1656,7 @@ function statusnet_convertmsg($a, $body, $no_tags = false) {
} else
$str_tags .= "@[url=".$mtch[2]."]".$mtch[3]."[/url]";
// To-Do:
- // There is a problem with links with to GNU Social groups, so these links are stored with "@" like friendica groups
+ // There is a problem with links with to statusnet groups, so these links are stored with "@" like friendica groups
//$str_tags .= $mtch[1]."[url=".$mtch[2]."]".$mtch[3]."[/url]";
}
}
@@ -35,7 +35,7 @@
/***
- * We have to alter the TwitterOAuth class a little bit to work with any GNU Social
+ * We have to alter the TwitterOAuth class a little bit to work with any StatusNet
* installation abroad. Basically it's only make the API path variable and be happy.
*
@@ -178,7 +178,7 @@ function statusnet_settings_post ($a,$post) {
if (isset($_POST['statusnet-preconf-apiurl'])) {
/***
- * If the user used one of the preconfigured GNU Social server credentials
+ * If the user used one of the preconfigured StatusNet server credentials
* use them. All the data are available in the global config.
* Check the API Url never the less and blame the admin if it's not working ^^
@@ -200,7 +200,7 @@ function statusnet_settings_post ($a,$post) {
} else {
if (isset($_POST['statusnet-consumersecret'])) {
- // check if we can reach the API of the GNU Social server
+ // check if we can reach the API of the StatusNet server
// we'll check the API Version for that, if we don't get one we'll try to fix the path but will
// resign quickly after this one try to fix the path ;-)
@@ -222,18 +222,18 @@ function statusnet_settings_post ($a,$post) {
$csecret = get_pconfig(local_user(), 'statusnet', 'consumersecret' );
// the token and secret for which the PIN was generated were hidden in the settings
- // form as token and token2, we need a new connection to GNU Social using these token
+ // form as token and token2, we need a new connection to StatusNet using these token
// and secret to request a Access Token with the PIN
$connection = new StatusNetOAuth($api, $ckey, $csecret, $_POST['statusnet-token'], $_POST['statusnet-token2']);
@@ -304,14 +304,14 @@ function statusnet_settings(&$a,&$s) {
$globalsn = get_config('statusnet', 'sites');
/***
- * lets check if we have one or more globally configured GNU Social
+ * lets check if we have one or more globally configured StatusNet
* server OAuth credentials in the configuration. If so offer them
* with a little explanation to the user as choice - otherwise